@@ -15,7 +15,7 @@ from .conf import product_list
 @pytest.fixture
 def test_obj(base_url, browser, browser_version, os_version, os_name, remote_flag, testrail_flag, tesults_flag,
              test_run_id, remote_project_name, remote_build_name, testname, reportportal_service, interactivemode_flag,
-             test_env, screenshot_option, xlsx_config, product):
+             test_env, screenshot_option, xlsx_config, product, non_breakable):
     "Return an instance of Base Page that knows about the third party integrations"
     try:
 
@@ -27,6 +27,7 @@ def test_obj(base_url, browser, browser_version, os_version, os_name, remote_fla
         #             browser, browser_version, os_version, os_name, remote_flag, testrail_flag, tesults_flag)
         test_obj = Zero_Page(base_url="http://", product=product_list.QCare)
         test_obj.test_env = test_env
+        test_obj.non_breakable = non_breakable
         test_obj.screenshot = screenshot_option
         test_obj.set_calling_module(testname)
         test_obj.product = product
@@ -140,19 +141,39 @@ def test_run_id(request):
         print("Python says:%s" % str(e))
 
 
+@pytest.fixture()
+def testID(request):
+    if request.config.getoption("--bdd_flag") == 'Y':
+        for i in request.node.own_markers:
+            if i.name.startswith('ID_BDD'):
+                return i.name
+    else:
+        raise Exception("Unable to find testID marker. It should start with ID_BDD if running with is_bdd "
+                        "arguement=Y. It should be second parameterize if not runnign with bdd")
+
+
 @pytest.fixture
-def cases(request):
+def non_breakable(request):
+    "pytest fixture for app activity"
+    try:
+        return request.config.getoption("--non_breakable")
+
+    except Exception as e:
+        print("Exception when trying to run test: %s" % __file__)
+        print("Python says:%s" % str(e))
+
+
+
+@pytest.fixture
+def cases(request, product, testID):
     name = request.config.getoption("--xlsx")
-    testID = request.node.own_markers[0].args[1][0][1]
     sheet = "Context"
-    df = pd.read_excel("././conf/web/" + request.node.funcargs.get('product') + '/' + name, sheet_name=sheet, dtype=str,
-                       usecols=lambda x: 'Remark' not in x)
+    df = pd.read_excel("././conf/web/" + product + '/' + name, sheet_name=sheet, dtype=str, usecols=lambda x: 'Remark' not in x)
     df = df.fillna('')
     row = df.index[df['testID'] == testID].tolist()
     data = (df.loc[row[0]])
     return data
 
-
 @pytest.fixture
 def testrail_flag(request):
     "pytest fixture for test rail flag"
@@ -340,6 +361,14 @@ def pytest_addoption(parser):
                          dest="caseid",
                          default='',
                          help="Case ID which need to run in Excel config. Do no use this option for running all cases. Only support 1 case")
+        parser.addoption("--bdd_flag",
+                         dest="bdd_flag",
+                         default='N',
+                         help="Determine if the run is in BDD: Y or N")
+        parser.addoption("--non_breakable",
+                         dest="non_breakable",
+                         default='N',
+                         help="Determine when failure happen, the flow will break or not")
     except Exception as e:
         print("Exception when trying to run test: %s" % __file__)
         print("Python says:%s" % str(e))
