@@ -298,17 +298,43 @@ class Base_Page(Borg, unittest.TestCase):
             self.write(str(e))
             self.exceptions.append("Error when setting up the screenshot directory")
 
-    def assert_true(self, condition, message=None):
+    def assert_true(self, condition, error_message=None, level='info'):
         if self.non_breakable == 'N':
-            assert_that(condition, equal_to(True), message)
+            assert_that(condition, equal_to(True), error_message)
         elif self.non_breakable == 'Y':
             print('testing')
+            self.mini_check_counter += 1
+            if level.lower() == "inverse":
+                if condition is True:
+                    self.write("action performed", level='error')
+                else:
+                    self.write(error_message, level='info')
+                    self.mini_check_pass_counter += 1
+            else:
+                if condition is True:
+                    self.write("action performed", level='info')
+                    self.mini_check_pass_counter += 1
+                else:
+                    self.write(error_message, level='error')
 
-    def assert_false(self, condition, message=None):
+    def assert_false(self, condition, error_message=None, level='info'):
         if self.non_breakable == 'N':
-            assert_that(condition, equal_to(False), message)
+            assert_that(condition, equal_to(False), error_message)
         elif self.non_breakable == 'Y':
             print('testing')
+            self.mini_check_counter += 1
+            if level.lower() == "inverse":
+                if condition is True:
+                    self.write("action performed", level='error')
+                else:
+                    self.write(error_message, level='info')
+                    self.mini_check_pass_counter += 1
+            else:
+                if condition is True:
+                    self.write("action performed", level='info')
+                    self.mini_check_pass_counter += 1
+                else:
+                    self.write(error_message, level='error')
 
     def get_screenshot_dir(self, os_name, os_version, browser, browser_version, overwrite_flag=False):
         "Get the name of the test"
